@@ -20,7 +20,7 @@ extern "C" {
 #include <sys/utime.h>
 
 #define snprintf _snprintf
-#define lstat _stat
+#define lstat stat
 
 #define realpath(N,R) _fullpath((R),(N),MAXPATHLEN)
 #define ftruncate(fildes,length) open(fildes, O_TRUNC|O_WRONLY)
@@ -31,13 +31,19 @@ extern "C" {
 #define getuid(x) 0
 #define geteuid() 0
 #define chown(outfname,st_uid,st_gid) 0
+
+#ifndef S_ISREG
 #define S_ISREG(mode)  (((mode) & S_IFMT) == S_IFREG)
+#endif
+
+#ifndef S_ISDIR
 #define S_ISDIR(mode)  (((mode) & S_IFMT) == S_IFDIR)
+#endif
 
 #ifndef HOST_TYPE
 #if _WIN64
 #define HOST_TYPE "Win64"
-#else if WIN32
+#elif WIN32
 #define HOST_TYPE "Win32"
 #endif 
 #endif
